<template>
    <div>
        <el-upload
            :action="upload"
            list-type="picture-card"
            :auto-upload="true"
            :multiple="true"
            :headers="headers"
            :file-list="fileList"
            :on-success="success"
            :on-error="error"
            :data="updata"
            :on-exceed="handleExceed"
            :before-upload="uploadBeforeFile"
            v-loading.fullscreen="loading"
            :disabled="disabled"
            :class="['upload', {'disable-upload': disabled}]"
        >
            <i slot="default" class="el-icon-plus"></i>
            <div slot="file" slot-scope="{file}" style="width: 100%; height: 100%">
                <!-- {{file}} -->
                <template v-if="file.name">
                    <img
                        v-if="
                            file.name.split('.')[1] == 'jpg' ||
                            file.name.split('.')[1] == 'JPG' ||
                            file.name.split('.')[1] == 'jpeg' ||
                            file.name.split('.')[1] == 'JPEG' ||
                            file.name.split('.')[1] == 'png' ||
                            file.name.split('.')[1] == 'PNG' ||
                            file.name.split('.')[1] == 'bmp' ||
                            file.name.split('.')[1] == 'BMP' ||
                            file.name.split('.')[1] == 'gif' ||
                            file.name.split('.')[1] == 'GIF'
                        "
                        class="el-upload-list__item-thumbnail"
                        :src="file.url"
                        alt=""
                    />
                </template>
                <img
                    v-else
                    class="el-upload-list__item-thumbnail"
                    src="../../assets/downImg/文件夹.png"
                    alt=""
                />
                <span class="el-upload-list__item-actions">
                    <span
                        class="el-upload-list__item-preview"
                        @click="handlePictureCardPreview(file)"
                    >
                        <i class="el-icon-zoom-in"></i>
                    </span>
                    <span
                        class="el-upload-list__item-delete"
                        @click="handleDownload(file)"
                    >
                        <i class="el-icon-download"></i>
                    </span>
                    <span
                        v-if="!disabled"
                        class="el-upload-list__item-delete"
                        @click="handleRemove(file)"
                    >
                        <i class="el-icon-delete"></i>
                    </span>
                </span>
            </div>
        </el-upload>
        <el-dialog
            append-to-body
            :visible.sync="updialogVisible"
            :close-on-click-modal="false"
            :close-on-press-escape="false"
            title="附件预览"
        >
            <img width="100%" :src="dialogImageUrl" alt="" />
        </el-dialog>
    </div>
</template>

<script>
import {mapState} from 'vuex'
import basicData from '@/api/basicData.js'
import req from '@/request.js'
export default {
    props: {
        dadToSon: {
            type: Object,
            default: () => {},
        },
        limit: {
            type: Number,
            default: () => 5,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
    },
    data() {
        return {
            updata: {
                bizPath: this.dadToSon.bizPath,
            },
            dialogImageUrl: '',
            updialogVisible: false,
            fileList: [],
            loading: false,
            disabledBtn: false, //按钮禁用控制
        }
    },
    mounted() {
        this.dadToSon.fileList.forEach((item) => {
            item.name = item.attachmentName || ''
            item.url = item.attachmentPath || ''
        })
        this.fileList = this.dadToSon.fileList
    },
    watch: {
        dadToSon(newVal) {
            this.fileList = newVal.fileList
        },
    },
    created() {},
    computed: mapState({
        deleteUrl: function () {
            return (
                window.context.yhxt +
                '/bizMigrantBuildersInformation/v1/updateMigrantWorkersInformation'
            )
        },
        headers: (state) => {
            return {Authorization: `Bearer ${state.login.currentUser.token}`}
        },
        upload: function () {
            return window.context.yhxt + '/bizAccessory/v1/minioUpload'
        },
    }),
    methods: {
        handleExceed(file, fileList) {
            if (file.length > this.limit) {
                this.$message.warning(
                    `上传个数超过限制个数，最多上传${this.limit}个！！！`
                )
            }
        },
        uploadBeforeFile() {
            this.loading = true
        },
        error() {
            this.loading = false
        },
        success(response, file, fileList) {
            console.log(response, file, fileList, 'ddddddddd')
            this.loading = false
            this.$message({
                type: response.state == true ? 'success' : 'warning',
                message: response.state == true ? '上传成功' : '上传失败',
            })
            let imgList = []
            fileList.forEach((item) => {
                if (!item.id) {
                    if (item.response) {
                        imgList.push(item.response.value)
                    }
                } else {
                    imgList.push(item)
                }
            })
            this.fileList = fileList
            this.$emit('sonToDad1')
            this.$emit('sonToDad', imgList)
        },
        //删除事件
        handleRemove(file) {
            let INdex = this.fileList.findIndex((item) => {
                return item.uid == file.uid
            })
            this.fileList.splice(INdex, 1)
            let imgList = []
            this.fileList.forEach((item) => {
                if (!item.id) {
                    if (item.response) {
                        imgList.push(item.response.value)
                    }
                } else {
                    imgList.push(item)
                }
            })
            this.$emit('sonToDad', imgList)
            if (file.id) {
                basicData.deleteEnclosureManagement(file.id).then((res) => {})
            }
        },
        handlePictureCardPreview(file) {
            if (
                file.name.split('.')[1] == 'jpg' ||
                file.name.split('.')[1] == 'JPG' ||
                file.name.split('.')[1] == 'jpeg' ||
                file.name.split('.')[1] == 'JPEG' ||
                file.name.split('.')[1] == 'png' ||
                file.name.split('.')[1] == 'PNG' ||
                file.name.split('.')[1] == 'bmp' ||
                file.name.split('.')[1] == 'BMP' ||
                file.name.split('.')[1] == 'gif' ||
                file.name.split('.')[1] == 'GIF'
            ) {
                this.dialogImageUrl = file.url
            } else {
                this.dialogImageUrl = require('../../assets/downImg/文件夹.png')
            }
            this.updialogVisible = true
        },
        handleDownload(file) {
            if (file.id) {
                req.downloadGetCopy(
                    window.context.yhxt +
                        `/bizEngineeringAccessories/v1/minIoAllDownFile?bizPath=${this.dadToSon.bizPath}&ids=${file.id}`
                ).then((res) => {
                    if (res) {
                        this.$message.success('下载成功')
                    }
                })
            } else {
                this.$message.info('请先保存附件')
            }
        },
    },
}
</script>

<style lang="scss" scoped>
.el-upload-list__item-thumbnail {
    width: 100%;
    height: 100%;
}
.disable-upload{
    /deep/.el-upload.el-upload--picture-card{
        cursor: not-allowed;
    }
}
</style>
